pub struct InputOpts {
pub exec: bool,
pub input: String,
}Fields
exec: boolTreat input as code, evaluate them instead of reading file
input: StringPath to the file to be compiled if --evaluate is unset, otherwise code itself